@@ -10,7 +10,13 @@ describe 'cinder::db::sync' do
         :user        => 'cinder',
         :path        => '/usr/bin',
         :refreshonly => 'true',
-        :logoutput   => 'on_failure'
+        :try_sleep   => 5,
+        :tries       => 10,
+        :logoutput   => 'on_failure',
+        :subscribe   => ['Anchor[cinder::install::end]',
+                         'Anchor[cinder::config::end]',
+                         'Anchor[cinder::dbsync::begin]'],
+        :notify      => 'Anchor[cinder::dbsync::end]',
       )
     end
 
@@ -27,7 +33,13 @@ describe 'cinder::db::sync' do
           :user        => 'cinder',
           :path        => '/usr/bin',
           :refreshonly => 'true',
-          :logoutput   => 'on_failure'
+          :try_sleep   => 5,
+          :tries       => 10,
+          :logoutput   => 'on_failure',
+          :subscribe   => ['Anchor[cinder::install::end]',
+                         'Anchor[cinder::config::end]',
+                         'Anchor[cinder::dbsync::begin]'],
+          :notify      => 'Anchor[cinder::dbsync::end]',
         )
       }
     end
